==> puppet-designate-9.5.0.tar.gz: openstack-designate-9.5.0/spec/classes/designate_db_sync_spec.rb <==
#
# Unit tests for designate::db::sync
#
require 'spec_helper'

describe 'designate::db::sync' do

  shared_examples_for 'designate-db-sync' do
    context 'with default parameters' do
      it 'runs designate-db-sync' do
        is_expected.to contain_exec('designate-dbsync').with(
          :command     => 'designate-manage  database sync',
          :path        => '/usr/bin',
          :user        => 'root',
          :refreshonly => 'true',
          :logoutput   => 'on_failure',
          :subscribe   => 'Anchor[designate::config::end]',
          :notify      => 'Anchor[designate::service::begin]',
        )
      end
    end

    context 'with parameter overrides' do
      let :params do
        {
          :extra_params => '--config-file /etc/designate/designate.conf'
        }
      end
      it 'runs designate manage with diffent config' do
        is_expected.to contain_exec('designate-dbsync').with(
          :command     => 'designate-manage --config-file /etc/designate/designate.conf database sync',
          :path        => '/usr/bin',
          :user        => 'root',
          :refreshonly => 'true',
          :logoutput   => 'on_failure',
          :subscribe   => 'Anchor[designate::config::end]',
          :notify      => 'Anchor[designate::service::begin]',
        )
      end
    end
  end

  on_supported_os({
    :supported_os => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge!(OSDefaults.get_facts())
      end

      it_behaves_like 'designate-db-sync'
    end
  end
end

==> puppet-designate-11.6.0.tar.gz: openstack-designate-11.6.0/spec/classes/designate_db_sync_spec.rb <==
#
# Unit tests for designate::db::sync
#
require 'spec_helper'

describe 'designate::db::sync' do

  shared_examples_for 'designate-db-sync' do
    context 'with default parameters' do
      it 'runs designate-db-sync' do
        is_expected.to contain_exec('designate-dbsync').with(
          :command     => 'designate-manage  database sync',
          :path        => '/usr/bin',
          :user        => 'root',
          :refreshonly => 'true',
          :logoutput   => 'on_failure',
          :subscribe   => ['Anchor[designate::install::end]',
                           'Anchor[designate::config::end]',
                           'Anchor[designate::dbsync::begin]'],
          :notify      => 'Anchor[designate::dbsync::end]',
          :tag         => 'openstack-db',
        )
      end
    end

    context 'with parameter overrides' do
      let :params do
        {
          :extra_params => '--config-file /etc/designate/designate.conf'
        }
      end
      it 'runs designate manage with diffent config' do
        is_expected.to contain_exec('designate-dbsync').with(
          :command     => 'designate-manage --config-file /etc/designate/designate.conf database sync',
          :path        => '/usr/bin',
          :user        => 'root',
          :refreshonly => 'true',
          :logoutput   => 'on_failure',
          :subscribe   => ['Anchor[designate::install::end]',
                           'Anchor[designate::config::end]',
                           'Anchor[designate::dbsync::begin]'],
          :notify      => 'Anchor[designate::dbsync::end]',
          :tag         => 'openstack-db',
        )
      end
    end
  end

  on_supported_os({
    :supported_os => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge!(OSDefaults.get_facts())
      end

      it_behaves_like 'designate-db-sync'
    end
  end
end
